
# Slot: unique_keys


Set of unique keys for this slot

URI: [linkml:unique_keys](https://w3id.org/linkml/unique_keys)


## Domain and Range

[ClassDefinition](ClassDefinition.md) &#8594;  <sub>0..\*</sub> [UniqueKey](UniqueKey.md)

## Parents


## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | owl:hasKey |

